#[repr(transparent)]pub struct HistoryTrackerNeighborInfo(pub otHistoryTrackerNeighborInfo);Expand description
This structure represents a Thread neighbor info in the history tracker report.
Functional equivalent of otsys::otHistoryTrackerNeighborInfo.
Tuple Fields
0: otHistoryTrackerNeighborInfoImplementations
Sourceimpl HistoryTrackerNeighborInfo
impl HistoryTrackerNeighborInfo
Sourcepub fn ext_address(&self) -> ExtAddress
pub fn ext_address(&self) -> ExtAddress
Returns Neighbor’s Extended Address.
Sourcepub fn avg_rssi(&self) -> i8
pub fn avg_rssi(&self) -> i8
Returns the Average RSSI of rx frames from neighbor at the time of recording entry.
Sourcepub fn event(&self) -> HistoryTrackerNeighborEvent
pub fn event(&self) -> HistoryTrackerNeighborEvent
Returns the neighbor event (OT_HISTORY_TRACKER_NEIGHBOR_EVENT_* enumeration).
Sourcepub fn rx_on_while_idle(&self) -> bool
pub fn rx_on_while_idle(&self) -> bool
Returns true if the neighbor has its receiver on when not transmitting.
Sourcepub fn full_thread_device(&self) -> bool
pub fn full_thread_device(&self) -> bool
Returns true if the neighbor is a Full Thread Device.
Sourcepub fn full_network_data(&self) -> bool
pub fn full_network_data(&self) -> bool
Returns true if the neighbor requires the full Network Data.