#[repr(transparent)]pub struct MleCounters(pub otMleCounters);Expand description
This structure represents the MLE layer counters.
Functional equivalent of otsys::otMleCounters.
Tuple Fields
0: otMleCountersImplementations
Sourceimpl MleCounters
impl MleCounters
Sourcepub fn disabled_role(&self) -> u16
pub fn disabled_role(&self) -> u16
Number of times device entered OT_DEVICE_ROLE_DISABLED role.
Sourcepub fn detached_role(&self) -> u16
pub fn detached_role(&self) -> u16
Number of times device entered OT_DEVICE_ROLE_DETACHED role.
Sourcepub fn child_role(&self) -> u16
pub fn child_role(&self) -> u16
Number of times device entered OT_DEVICE_ROLE_CHILD role.
Sourcepub fn router_role(&self) -> u16
pub fn router_role(&self) -> u16
Number of times device entered OT_DEVICE_ROLE_ROUTER role.
Sourcepub fn leader_role(&self) -> u16
pub fn leader_role(&self) -> u16
Number of times device entered OT_DEVICE_ROLE_LEADER role.
Sourcepub fn attach_attempts(&self) -> u16
pub fn attach_attempts(&self) -> u16
Number of attach attempts while device was detached.
Sourcepub fn partition_id_changes(&self) -> u16
pub fn partition_id_changes(&self) -> u16
Number of changes to partition ID.
Sourcepub fn better_partition_attach_attempts(&self) -> u16
pub fn better_partition_attach_attempts(&self) -> u16
Number of attempts to attach to a better partition.
Sourcepub fn better_parent_attach_attempts(&self) -> u16
pub fn better_parent_attach_attempts(&self) -> u16
Number of attempts to attach to find a better parent (parent search).
Sourcepub fn disabled_time(&self) -> u64
pub fn disabled_time(&self) -> u64
Number of milliseconds device has been in OT_DEVICE_ROLE_DISABLED role.
Sourcepub fn detached_time(&self) -> u64
pub fn detached_time(&self) -> u64
Number of milliseconds device has been in OT_DEVICE_ROLE_DETACHED role.
Sourcepub fn child_time(&self) -> u64
pub fn child_time(&self) -> u64
Number of milliseconds device has been in OT_DEVICE_ROLE_CHILD role.
Sourcepub fn router_time(&self) -> u64
pub fn router_time(&self) -> u64
Number of milliseconds device has been in OT_DEVICE_ROLE_ROUTER role.
Sourcepub fn leader_time(&self) -> u64
pub fn leader_time(&self) -> u64
Number of milliseconds device has been in OT_DEVICE_ROLE_LEADER role.
Sourcepub fn tracked_time(&self) -> u64
pub fn tracked_time(&self) -> u64
Number of milliseconds tracked by previous counters.
Sourcepub fn parent_changes(&self) -> u16
pub fn parent_changes(&self) -> u16
Number of times device changed its parent.