#[repr(transparent)]pub struct MultiRadioNeighborInfo(pub otMultiRadioNeighborInfo);Expand description
This structure represents multi radio link information associated with a neighbor.
Functional equivalent of otsys::otMultiRadioNeighborInfo.
Tuple Fields
0: otMultiRadioNeighborInfoImplementations
Sourceimpl MultiRadioNeighborInfo
impl MultiRadioNeighborInfo
Sourcepub fn is_ieee_802_15_4_supported(&self) -> bool
pub fn is_ieee_802_15_4_supported(&self) -> bool
Whether the neighbor supports IEEE 802.15.4 radio link.
Sourcepub fn is_trel_supported(&self) -> bool
pub fn is_trel_supported(&self) -> bool
Whether the neighbor supports Thread Radio Encapsulation Link (TREL) radio link.
Sourcepub fn ieee_802_15_4_preference(&self) -> u8
pub fn ieee_802_15_4_preference(&self) -> u8
Preference level for the IEEE 802.15.4 radio link.
Sourcepub fn trel_preference(&self) -> u8
pub fn trel_preference(&self) -> u8
Preference level for the Thread Radio Encapsulation Link (TREL) radio link.