ProcessPollAsync

Trait ProcessPollAsync 

pub trait ProcessPollAsync {
    // Required method
    fn process_poll(&self, cx: &mut Context<'_>) -> Poll<Option<()>>;
}
Trait that provides the [process_poll()] method.

Required Methods

fn process_poll(&self, cx: &mut Context<'_>) -> Poll<Option<()>>

Processes all tasks that need to be handled for this instance, including those from the platform implementation.

Dyn Compatibility

This trait is dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementors