pub trait TaskletsStreamExt {
// Required method
fn tasklets_poll(&self, cx: &mut Context<'_>) -> Poll<Option<()>>;
// Provided method
fn tasklets_stream(&self) -> TaskletsStream<'_, Self> { ... }
}Expand description
Trait used to wrap around a mutex that polls internally without needing to externally unlock the mutex.
Required Methods
Provided Methods
Sourcefn tasklets_stream(&self) -> TaskletsStream<'_, Self>
fn tasklets_stream(&self) -> TaskletsStream<'_, Self>
Returns an asynchronous stream which can be used for processing tasklets.
Dyn Compatibility
This trait is not dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".