HistoryTracker

Trait HistoryTracker 

pub trait HistoryTracker {
    // Required methods
    fn history_tracker_init_iterator(&self, iter: &mut otHistoryTrackerIterator);
    fn iter_next_net_info_history(
        &self,
        ot_iter: &mut otHistoryTrackerIterator,
        entry_age: &mut u32,
    ) -> Option<HistoryTrackerNetworkInfo>;
    fn iter_next_neighbor_history(
        &self,
        ot_iter: &mut otHistoryTrackerIterator,
        entry_age: &mut u32,
    ) -> Option<HistoryTrackerNeighborInfo>;
    fn iter_next_router_history(
        &self,
        ot_iter: &mut otHistoryTrackerIterator,
        entry_age: &mut u32,
    ) -> Option<HistoryTrackerRouterInfo>;
    fn iter_next_on_mesh_prefix_history(
        &self,
        ot_iter: &mut otHistoryTrackerIterator,
        entry_age: &mut u32,
    ) -> Option<HistoryTrackerOnMeshPrefixInfo>;
    fn iter_next_external_route_history(
        &self,
        ot_iter: &mut otHistoryTrackerIterator,
        entry_age: &mut u32,
    ) -> Option<HistoryTrackerExternalRouteInfo>;

    // Provided methods
    fn history_tracker_net_info_history_get_iterator(
        &self,
    ) -> HistoryTrackerNetInfoIterator<'_, Self>  { ... }
    fn history_tracker_neighbor_history_get_iterator(
        &self,
    ) -> HistoryTrackerNeighborIterator<'_, Self>  { ... }
    fn history_tracker_router_history_get_iterator(
        &self,
    ) -> HistoryTrackerRouterIterator<'_, Self>  { ... }
    fn history_tracker_on_mesh_prefix_history_get_iterator(
        &self,
    ) -> HistoryTrackerOnMeshPrefixIterator<'_, Self>  { ... }
    fn history_tracker_external_route_history_get_iterator(
        &self,
    ) -> HistoryTrackerExternalRouteIterator<'_, Self>  { ... }
}
Required Methods

fn history_tracker_init_iterator(&self, iter: &mut otHistoryTrackerIterator)

Functional equivalent of otsys::otHistoryTrackerInitIterator (crate::otsys::otHistoryTrackerInitIterator).

fn iter_next_net_info_history( &self, ot_iter: &mut otHistoryTrackerIterator, entry_age: &mut u32, ) -> Option<HistoryTrackerNetworkInfo>

Functional equivalent of otsys::otHistoryTrackerIterateNetInfoHistory (crate::otsys::otHistoryTrackerIterateNetInfoHistory).

fn iter_next_neighbor_history( &self, ot_iter: &mut otHistoryTrackerIterator, entry_age: &mut u32, ) -> Option<HistoryTrackerNeighborInfo>

Functional equivalent of otsys::otHistoryTrackerIterateNeighborHistory (crate::otsys::otHistoryTrackerIterateNeighborHistory).

fn iter_next_router_history( &self, ot_iter: &mut otHistoryTrackerIterator, entry_age: &mut u32, ) -> Option<HistoryTrackerRouterInfo>

Functional equivalent of otsys::otHistoryTrackerIterateRouterHistory (crate::otsys::otHistoryTrackerIterateRouterHistory).

fn iter_next_on_mesh_prefix_history( &self, ot_iter: &mut otHistoryTrackerIterator, entry_age: &mut u32, ) -> Option<HistoryTrackerOnMeshPrefixInfo>

Functional equivalent of otsys::otHistoryTrackerIterateOnMeshPrefixHistory (crate::otsys::otHistoryTrackerIterateOnMeshPrefixHistory).

fn iter_next_external_route_history( &self, ot_iter: &mut otHistoryTrackerIterator, entry_age: &mut u32, ) -> Option<HistoryTrackerExternalRouteInfo>

Functional equivalent of otsys::otHistoryTrackerIterateExternalRouteHistory (crate::otsys::otHistoryTrackerIterateExternalRouteHistory).

Provided Methods

fn history_tracker_net_info_history_get_iterator( &self, ) -> HistoryTrackerNetInfoIterator<'_, Self>

Get the history tracker net info history iterator instance.

fn history_tracker_neighbor_history_get_iterator( &self, ) -> HistoryTrackerNeighborIterator<'_, Self>

Get the history tracker neighbor info history iterator instance.

fn history_tracker_router_history_get_iterator( &self, ) -> HistoryTrackerRouterIterator<'_, Self>

Get the history tracker router info history iterator instance.

fn history_tracker_on_mesh_prefix_history_get_iterator( &self, ) -> HistoryTrackerOnMeshPrefixIterator<'_, Self>

Get the history tracker netdata on-mesh prefix info history iterator instance.

fn history_tracker_external_route_history_get_iterator( &self, ) -> HistoryTrackerExternalRouteIterator<'_, Self>

Get the history tracker netdata external route info history iterator instance.

Dyn Compatibility

This trait is not dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety", so this trait is not object safe.

Implementors