pub trait InfraInterface {
// Required methods
fn plat_infra_if_on_state_changed(&self, id: u32, is_running: bool);
fn plat_infra_if_discover_nat64_prefix_done(
&self,
infra_if_idx: u32,
ip6_prefix: Ip6Prefix,
);
}Expand description
Methods from the “Platform Infrastructure Interface” group [1]
[1] https://openthread.io/reference/group/plat-infra-if
Required Methods
Sourcefn plat_infra_if_on_state_changed(&self, id: u32, is_running: bool)
fn plat_infra_if_on_state_changed(&self, id: u32, is_running: bool)
The infra interface driver calls this method to notify OpenThread of the interface state changes.
Sourcefn plat_infra_if_discover_nat64_prefix_done(
&self,
infra_if_idx: u32,
ip6_prefix: Ip6Prefix,
)
fn plat_infra_if_discover_nat64_prefix_done( &self, infra_if_idx: u32, ip6_prefix: Ip6Prefix, )
The infra interface driver calls this method to notify OpenThread that the discovery of NAT64 prefix is done.
Dyn Compatibility
This trait is dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".